<html>
<head>
  <link rel="stylesheet" href="https://unpkg.com/purecss@1.0.1/build/pure-min.css" integrity="sha384-oAOxQR6DkCoMliIh8yFnu25d7Eq/PHS21PClpwjOTeU2jRSq11vu66rf90/cZr47" crossorigin="anonymous">
</head>
<body>
  <style>
  td,th {{ padding: .5em; }}
  </style>
  <div class="pure-g">
    <div class="pure-u-1-12">
      <a class="pure-button" href="{first}">&lt;&lt;</a>
      <a class="pure-button" href="{prev}">&lt;</a>
    </div>
    <div class="pure-u-1-8">
      <p>Page {page} of {pages}</p>
    </div>
    <div class="pure-u-1-12">
      <a class="pure-button" href="{next}">&gt;</a>
      <a class="pure-button" href="{last}">&gt;&gt;</a>
    </div>
    <div class="pure-u-1-12">
      <form class="pure-form" action="." method="GET">
          <input type="hidden" name="query" value='{query}' />
          <input type="text" name="page" placeholder="Go to page" />
      </form>
    </div>
  </div> <!-- .pure-g -->

  <div class="pure-g">
    <div class="pure-u-1-2">
      <form action="." method="GET" class="pure-form">
        Query: <input type="text" name="query" placeholder='{query}' class="pure-input-1-2"/>
      </form>
    </div>
  </div> <!-- .pure-g -->
  <div class="pure-g">
    <div class="pure-u-1-1">
      {html}
    </div>
  </div> <!-- .pure-g -->
</body>
</html>
